summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2002-08-23 11:04:59 +0000
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2002-08-23 11:04:59 +0000
commit2a3e8f2d2c5733975d260f2c39263144cdd986cf (patch)
tree6061eca254f07bd32b9610401c1f07e49c3fbdbe
parentceb0ce2bf63c99fea35e8110936ee6e915f1e4cd (diff)
downloadgnutls-2a3e8f2d2c5733975d260f2c39263144cdd986cf.tar.gz
Exported gnutls_openpgp_extract_key_id(). This is the gnutls_openpgp_keyid() function renamed.
-rw-r--r--includes/gnutls/extra.h2
-rw-r--r--libextra/gnutls_openpgp.c8
-rw-r--r--libextra/gnutls_openpgp.h2
3 files changed, 7 insertions, 5 deletions
diff --git a/includes/gnutls/extra.h b/includes/gnutls/extra.h
index 4d4d705dea..3970a12ddc 100644
--- a/includes/gnutls/extra.h
+++ b/includes/gnutls/extra.h
@@ -70,6 +70,8 @@ int gnutls_openpgp_extract_key_version( const gnutls_datum *cert );
time_t gnutls_openpgp_extract_key_creation_time( const gnutls_datum *cert );
time_t gnutls_openpgp_extract_key_expiration_time( const gnutls_datum *cert );
+int gnutls_openpgp_extract_key_id( const gnutls_datum *cert, unsigned char keyid[8]);
+
int gnutls_openpgp_verify_key( const gnutls_datum* keyring,
const gnutls_datum* key_list,
int key_list_length);
diff --git a/libextra/gnutls_openpgp.h b/libextra/gnutls_openpgp.h
index 7c8d1de56c..fb0c5ba5ea 100644
--- a/libextra/gnutls_openpgp.h
+++ b/libextra/gnutls_openpgp.h
@@ -48,7 +48,7 @@ int gnutls_openpgp_fingerprint(
char *fpr,
size_t *fprlen );
-int gnutls_openpgp_keyid(
+int gnutls_openpgp_extract_key_id(
const gnutls_datum *cert,
unsigned char keyid[8] );
diff --git a/libextra/gnutls_openpgp.c b/libextra/gnutls_openpgp.c
index 9356b63f75..0434723aac 100644
--- a/libextra/gnutls_openpgp.c
+++ b/libextra/gnutls_openpgp.c
@@ -1193,15 +1193,15 @@ gnutls_openpgp_fingerprint(const gnutls_datum *cert, char *fpr, size_t *fprlen)
return 0;
}
/*-
* gnutls_openpgp_keyid - Gets the keyID
* @cert: the raw data that contains the OpenPGP public key.
* @keyid: the buffer to save the keyid.
*
* Returns the 64-bit keyID of the OpenPGP key.
- -*/
+ **/
int
-gnutls_openpgp_keyid( const gnutls_datum *cert, unsigned char keyid[8] )
+gnutls_openpgp_extract_key_id( const gnutls_datum *cert, unsigned char keyid[8] )
{
CDK_KBNODE kb_pk = NULL, pkt;
cdkPKT_public_key *pk = NULL;
@@ -1193,15 +1193,15 @@ gnutls_openpgp_fingerprint(const gnutls_datum *cert, char *fpr, size_t *fprlen)
return 0;
}
-/*-
- * gnutls_openpgp_keyid - Gets the keyID
+/**
+ * gnutls_openpgp_extract_key_id - Gets the keyID
* @cert: the raw data that contains the OpenPGP public key.
* @keyid: the buffer to save the keyid.